@@ -2,7 +2,7 @@ struct Application;
 
 impl Application {
     fn new() -> Result<Self, wita::ApiError> {
-        wita::WindowBuilder::new().title("hello, world!").build()?;
+        wita::Window::builder().title("hello, world!").build()?;
         Ok(Self)
     }
 }
