@@ -2,6 +2,7 @@ use crate::geometry::*;
 #[cfg(feature = "serde")]
 use serde::{de::*, *};
 use windows::Win32::{Foundation::*, UI::Input::KeyboardAndMouse::*, UI::WindowsAndMessaging::*};
+use windows::core::PCWSTR;
 
 /// Describes the state of a keyboard key and a mouse button.
 #[derive(Clone, Copy, PartialEq, Eq, Debug, Hash)]
@@ -477,7 +478,7 @@ pub enum Cursor {
 }
 
 impl Cursor {
-    pub(crate) fn name(&self) -> PWSTR {
+    pub(crate) fn name(&self) -> PCWSTR {
         match self {
             Self::AppStarting => IDC_APPSTARTING,
             Self::Arrow => IDC_ARROW,
