@@ -76,6 +76,16 @@ pub trait EventHandler {
     /// This is called when the cursor has been leaved the window.
     fn cursor_leaved(&mut self, window: &Window, mouse_state: MouseState) {}
 
+    /// This is called when the mouse wheel has been rotated or tilted.
+    fn mouse_wheel(
+        &mut self,
+        window: &Window,
+        axis: Wheel,
+        distance: i32,
+        mouse_state: MouseState,
+    ) {
+    }
+
     /// This is called when the keyboard key has been pressed and released.
     fn key_input(
         &mut self,
