@@ -14,6 +14,7 @@ use windows::Win32::{
     Devices::HumanInterfaceDevice::*, Foundation::*, Storage::FileSystem::*,
     UI::Input::KeyboardAndMouse::*, UI::Input::*, UI::WindowsAndMessaging::*,
 };
+use windows::core::{PSTR, PCSTR, PCWSTR};
 
 const HID_USAGE_PAGE_GENERIC: u16 = 0x01;
 
@@ -96,7 +97,7 @@ unsafe fn get_device_interface(handle: HANDLE) -> Option<Vec<u16>> {
 
 unsafe fn get_device_name(interface: &[u16]) -> Option<String> {
     let handle = CreateFileW(
-        PWSTR(interface.as_ptr() as _),
+        PCWSTR(interface.as_ptr() as _),
         FILE_ACCESS_FLAGS(0),
         FILE_SHARE_READ | FILE_SHARE_WRITE,
         null_mut(),
@@ -746,7 +747,7 @@ unsafe fn input_data_gamepad(input: &mut RAWINPUT) -> Option<InputData> {
                 usage,
                 &mut value,
                 p,
-                PSTR(hid.bRawData.as_mut_ptr()),
+                PCSTR(hid.bRawData.as_mut_ptr()),
                 hid.dwSizeHid,
             );
             if ret.is_err() {
