@@ -1,9 +1,10 @@
 use std::path::{Path, PathBuf};
 use windows::Win32::{Foundation::*, UI::WindowsAndMessaging::*};
+use windows::core::{PCWSTR};
 
 #[inline]
-fn make_int_resource(id: u16) -> PWSTR {
-    PWSTR(id as _)
+fn make_int_resource(id: u16) -> PCWSTR {
+    PCWSTR(id as _)
 }
 
 /// Describes a icon.
