@@ -20,6 +20,7 @@ use windows::Win32::{
     Foundation::*, Graphics::Gdi::*, System::LibraryLoader::*, UI::HiDpi::*, UI::Shell::*,
     UI::WindowsAndMessaging::*,
 };
+use windows::core::PCWSTR;
 
 #[derive(Clone, PartialEq, Eq)]
 pub(crate) struct WindowHandle(HWND);
@@ -131,12 +132,12 @@ pub(crate) fn register_class<T: EventHandler + 'static>() {
             lpfnWndProc: Some(window_proc::<T>),
             cbClsExtra: 0,
             cbWndExtra: 0,
-            hInstance: GetModuleHandleW(PWSTR::default()),
+            hInstance: GetModuleHandleW(PCWSTR::default()),
             hIcon: HICON(0),
             hCursor: HCURSOR(0),
             hbrBackground: HBRUSH(GetStockObject(WHITE_BRUSH).0),
-            lpszMenuName: PWSTR::default(),
-            lpszClassName: PWSTR(class_name.as_ptr() as _),
+            lpszMenuName: PCWSTR::default(),
+            lpszClassName: PCWSTR(class_name.as_ptr() as _),
             hIconSm: HICON(0),
         };
         if RegisterClassExW(&wc) == 0 {
@@ -341,7 +342,7 @@ where
             let dpi = get_dpi_from_point(self.position);
             let inner_size = self.inner_size.to_physical(dpi);
             let rc = adjust_window_rect(inner_size, self.style, WINDOW_EX_STYLE(0), dpi);
-            let hinst = GetModuleHandleW(PWSTR::default());
+            let hinst = GetModuleHandleW(PCWSTR::default());
             let hwnd = CreateWindowExW(
                 if self.no_redirection_bitmap {
                     WS_EX_NOREDIRECTIONBITMAP
@@ -524,11 +525,11 @@ where
             let position = self.position.to_physical(dpi as i32);
             let size = self.size.to_physical(dpi);
             let rc = adjust_window_rect(size, WS_CHILD, WINDOW_EX_STYLE(0), dpi);
-            let hinst = GetModuleHandleW(PWSTR::default());
+            let hinst = GetModuleHandleW(PCWSTR::default());
             let hwnd = CreateWindowExW(
                 WINDOW_EX_STYLE(0),
                 WINDOW_CLASS_NAME,
-                PWSTR::default(),
+                PCWSTR::default(),
                 WS_CHILD,
                 position.x,
                 position.y,
@@ -846,7 +847,7 @@ unsafe impl HasRawWindowHandle for Window {
     #[inline]
     fn raw_window_handle(&self) -> RawWindowHandle {
         let mut handle = Win32Handle::empty();
-        handle.hinstance = unsafe { GetModuleHandleW(PWSTR::default()).0 as *mut std::ffi::c_void };
+        handle.hinstance = unsafe { GetModuleHandleW(PCWSTR::default()).0 as *mut std::ffi::c_void };
         handle.hwnd = self.hwnd.0 .0 as *mut std::ffi::c_void;
         RawWindowHandle::Win32(handle)
     }
